@@ -27,11 +27,11 @@ __all__ = ("DeploymentSuccessfulWaiter",)
 
 class DeploymentSuccessfulWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/codedeploy.html#CodeDeploy.Waiter.deployment_successful)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/waiters.html#deploymentsuccessfulwaiter)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/codedeploy.html#CodeDeploy.Waiter.deployment_successful)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/waiters.html#deploymentsuccessfulwaiter)
     """
 
-    def wait(self, deploymentId: str, WaiterConfig: WaiterConfigTypeDef = None) -> None:
+    def wait(self, *, deploymentId: str, WaiterConfig: WaiterConfigTypeDef = None) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/codedeploy.html#CodeDeploy.Waiter.DeploymentSuccessfulWaiter)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/codedeploy.html#CodeDeploy.Waiter.DeploymentSuccessfulWaiter)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/waiters.html#deploymentsuccessful)
         """
